@@ -67,6 +67,7 @@ Settings::Settings()
     mNewEmailMenuEnabled = false;
     mIndexFilesRereadIntervalSec = 0;
     mThunderbirdCmdLine = Utils::getDefaultThunderbirdCommand();
+    mForceIgnoreUnreadEmailsOnMinimize = false;
 }
 
 Settings::~Settings()
@@ -96,6 +97,7 @@ void Settings::save()
     out[ "common/showunreademailcount" ] = mShowUnreadEmailCount;
     out[ "common/ignoreStartUnreadCount" ] = ignoreStartUnreadCount;
     out[ "common/showDialogIfNoAccountsConfigured"  ] = showDialogIfNoAccountsConfigured;
+    out[ "common/forceIgnoreUnreadEmailsOnMinimize"  ] = mForceIgnoreUnreadEmailsOnMinimize;
 
     out[ "advanced/tbcmdline" ] = QJsonArray::fromStringList( mThunderbirdCmdLine );
     out[ "advanced/tbwindowmatch" ] = mThunderbirdWindowMatch;
@@ -108,6 +110,7 @@ void Settings::save()
     out[ "advanced/ignoreUpdateVersion" ] = mIgnoreUpdateVersion;
     out[ ONLY_SHOW_ICON_ON_UNREAD_MESSAGES_KEY ] = onlyShowIconOnUnreadMessages;
     out[ "advanced/forcedRereadInterval" ] = static_cast<int>( mIndexFilesRereadIntervalSec );
+    out[ "advanced/runProcessOnChange" ] = mProcessRunOnCountChange;
 
     // Store the account map
     QJsonArray accounts;
@@ -134,10 +137,10 @@ void Settings::save()
     if ( !newemaildata.isEmpty() )
         out[ "newemails" ] = newemaildata;
 
-    if ( !mNotificationIconUnread.isNull() )
-        out[ "common/notificationiconunread" ] = pixmapToString( mNotificationIconUnread );
-
-    out[ "common/notificationicon" ] = pixmapToString( mNotificationIcon );
+    if ( !mNotificationIconUnread.isNull() ) {
+        out[ "common/notificationiconunread" ] = Utils::pixmapToString( mNotificationIconUnread );
+    }
+    out[ "common/notificationicon" ] = Utils::pixmapToString( mNotificationIcon );
 
     // QSaveFile is an I/O device for writing text and binary files, without
     // losing existing data if the writing operation fails.
@@ -199,8 +202,10 @@ void Settings::fromJSON( const QJsonObject& settings )
     if ( settings.contains( "common/notificationfont" ) )
         mNotificationFont.fromString( settings.value( "common/notificationfont" ).toString() );
 
-    mNotificationIcon = pixmapFromString( settings.value( "common/notificationicon" ).toString() );
-    mNotificationIconUnread = pixmapFromString(settings.value( "common/notificationiconunread" ).toString() );
+    mNotificationIcon = Utils::pixmapFromString(
+            settings.value("common/notificationicon").toString());
+    mNotificationIconUnread = Utils::pixmapFromString(
+            settings.value("common/notificationiconunread").toString());
 
     (void) getNotificationIcon(); // Load the default
 
@@ -226,6 +231,7 @@ void Settings::fromJSON( const QJsonObject& settings )
     mShowUnreadEmailCount = settings.value("common/showunreademailcount").toBool();
     ignoreStartUnreadCount = settings.value("common/ignoreStartUnreadCount").toBool();
     showDialogIfNoAccountsConfigured = settings.value("common/showDialogIfNoAccountsConfigured").toBool();
+    mForceIgnoreUnreadEmailsOnMinimize = settings.value( "common/forceIgnoreUnreadEmailsOnMinimize" ).toBool();
 
     mThunderbirdWindowMatch = settings.value("advanced/tbwindowmatch").toString();
     mNotificationMinimumFontSize = settings.value("advanced/notificationfontminsize").toInt();
@@ -237,6 +243,7 @@ void Settings::fromJSON( const QJsonObject& settings )
     onlyShowIconOnUnreadMessages = settings.value(ONLY_SHOW_ICON_ON_UNREAD_MESSAGES_KEY).toBool();
     mIgnoreUpdateVersion = settings.value("advanced/ignoreUpdateVersion").toString();
     mIndexFilesRereadIntervalSec = settings.value("advanced/forcedRereadInterval").toInt();
+    mProcessRunOnCountChange = settings.value( "advanced/runProcessOnChange" ).toString();
 
     QStringList thunderbirdCommand = settings.value("advanced/tbcmdline").toVariant().toStringList();
     if ( !thunderbirdCommand.isEmpty() && !thunderbirdCommand[0].isEmpty() )
@@ -285,8 +292,10 @@ void Settings::fromQSettings( QSettings * psettings )
     if ( settings.contains( "common/notificationfont" ) )
         mNotificationFont.fromString( settings.value( "common/notificationfont", "" ).toString() );
 
-    mNotificationIcon = pixmapFromString( settings.value("common/notificationicon","").toString() );
-    mNotificationIconUnread = pixmapFromString( settings.value("common/notificationiconunread","").toString() );
+    mNotificationIcon = Utils::pixmapFromString(
+            settings.value("common/notificationicon", "").toString());
+    mNotificationIconUnread = Utils::pixmapFromString(
+            settings.value("common/notificationiconunread", "").toString());
 
     (void) getNotificationIcon(); // Load the default
 
@@ -484,32 +493,6 @@ void Settings::setNotificationIcon(const QPixmap& icon) {
     mNotificationIcon = icon;
 }
 
-QString Settings::pixmapToString(const QPixmap &pixmap)
-{
-    // Store the notification icon in the icondata buffer
-    QByteArray icondata;
-    QBuffer buffer(&icondata);
-    buffer.open(QIODevice::WriteOnly);
-    pixmap.save(&buffer, "PNG");
-    buffer.close();
-
-    return QString::fromLatin1( icondata.toBase64() );
-}
-
-QPixmap Settings::pixmapFromString(const QString &data)
-{
-    QPixmap pix;
-
-    if ( !data.isEmpty() )
-    {
-        pix = QPixmap( mIconSize );
-        pix.loadFromData( QByteArray::fromBase64( data.toLatin1() ), "PNG" );
-        pix.detach();
-    }
-
-    return pix;
-}
-
 void Settings::loadInstallerConfiguration() {
     QStringList configDirs = QStandardPaths::standardLocations(QStandardPaths::AppConfigLocation);
     for (const QString& configDir : configDirs) {
