@@ -248,5 +248,17 @@
         <source>Lang_es</source>
         <translation>Spanisch</translation>
     </message>
+    <message>
+        <source>Lang_sv</source>
+        <translation>Schwedisch</translation>
+    </message>
+    <message>
+        <source>Lang_tr</source>
+        <translation>Türkisch</translation>
+    </message>
+    <message>
+        <source>Lang_pl</source>
+        <translation>Polnisch</translation>
+    </message>
 </context>
 </TS>
