@@ -248,5 +248,17 @@
         <source>Lang_es</source>
         <translation>Spanish</translation>
     </message>
+    <message>
+        <source>Lang_sv</source>
+        <translation>Swedish</translation>
+    </message>
+    <message>
+        <source>Lang_tr</source>
+        <translation>Turkish</translation>
+    </message>
+    <message>
+        <source>Lang_pl</source>
+        <translation>Polish</translation>
+    </message>
 </context>
 </TS>
