@@ -3,6 +3,7 @@
 #include <QPainter>
 #include <QProcess>
 #include <QMessageBox>
+#include <QPainterPath>
 #include <QtNetwork/QNetworkSession>
 
 #include "trayicon.h"
@@ -129,6 +130,23 @@ void TrayIcon::unreadCounterUpdate( unsigned int total, QColor color )
         }
     }
     
+    // Execute the hook process
+    if ( !BirdtrayApp::get()->getSettings()->mProcessRunOnCountChange.isEmpty() )
+    {
+        QString cmdline = BirdtrayApp::get()->getSettings()->mProcessRunOnCountChange;
+
+        // Replace the %NEW% with the new unread count
+        cmdline.replace( "%NEW%", QString::number( total ) );
+
+        // Replace the %OLD% with the old unread count
+        cmdline.replace( "%OLD%", QString::number( mUnreadCounter ) );
+
+        if ( !QProcess::startDetached( cmdline ) )
+            Log::debug( "Failed to execute hook command %s", qPrintable( cmdline ) );
+        else
+            Log::debug( "Executing hook command %s", qPrintable( cmdline ) );
+    }
+
     mUnreadCounter = total;
     mUnreadColor = color;
 
@@ -288,8 +306,14 @@ void TrayIcon::updateIcon()
                 continue;
             }
             QFileInfo accountMorkFile(path);
-            QString name = Utils::getMailAccountName(accountMorkFile)
-                           + " [" + Utils::getMailFolderName(accountMorkFile) + "]";
+            QString accountName = Utils::getMailAccountName(accountMorkFile);
+            QString mailFolderName = Utils::getMailFolderName(accountMorkFile);
+            QString name;
+            if (accountName.isNull() || mailFolderName.isNull()) {
+                name = path;
+            } else {
+                name = accountName + " [" + mailFolderName + "]";
+            }
             const QString &warning = warningsIterator.value();
             toolTip << name + ": " + warning;
         }
@@ -774,6 +798,9 @@ void TrayIcon::onAutoUpdateCheckFinished(bool foundUpdate, const QString &errorM
 
 void TrayIcon::hideThunderbird()
 {
+    if ( BirdtrayApp::get()->getSettings()->mForceIgnoreUnreadEmailsOnMinimize )
+        actionIgnoreEmails();
+
     mMenuShowHideThunderbird->setText( tr("Show Thunderbird") );
     mWinTools->hide();
 }
