@@ -4,8 +4,8 @@
 
 #include <QApplication>
 #include <QTextCodec>
-#include <QtWidgets/QMessageBox>
 #include <QtCore/QDir>
+#include <QtCore/QBuffer>
 
 #if defined (Q_OS_WIN)
 #  include <windows.h>
@@ -260,7 +260,9 @@ QString Utils::getMailFolderName(const QFileInfo &morkFile) {
         }
         name = QCoreApplication::translate(
                 "EmailFolders", dirName.toUtf8().constData()) + '/' + name;
-        parentDir.cdUp();
+        if (!parentDir.cdUp()) {
+            return QString();
+        }
     }
     return name;
 }
@@ -269,20 +271,39 @@ QString Utils::getMailAccountName(const QFileInfo &morkFile) {
     QDir parentDir = morkFile.dir();
     QString name;
     while ((name = parentDir.dirName()).endsWith(".sbd")) {
-        parentDir.cdUp();
+        if (!parentDir.cdUp()) {
+            return QString();
+        }
     }
     return name;
 }
 
 QString Utils::formatGithubMarkdown(const QString& markdown) {
     QString input = markdown;
-    static QRegularExpression githubMentionRegex(R"(((?<![^\s\n]))@(\S+))");
+    static QRegularExpression githubMentionRegex(
+            R"((?<!\w)@([a-z\d\-]+))", QRegularExpression::CaseInsensitiveOption);
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-    return input.replace(githubMentionRegex, R"(\1[@\2](https://github.com/\2))");
+    return input.replace(githubMentionRegex, R"([@\1](https://github.com/\1))");
 #else
     static QRegularExpression markdownLinksRegex(R"(\[(.+?)\]\((\S+?)\))");
-    return input.replace(githubMentionRegex, R"(@\1\2 (https://github.com/\2))")
+    return input.replace(githubMentionRegex, R"(@\1 (https://github.com/\1))")
                 .replace(markdownLinksRegex, R"(\1 (\2))");
 #endif
 }
 
+QString Utils::pixmapToString(const QPixmap &pixmap) {
+    QByteArray iconData;
+    QBuffer buffer(&iconData);
+    buffer.open(QIODevice::WriteOnly);
+    pixmap.save(&buffer, "PNG");
+    buffer.close();
+    return QString::fromLatin1(iconData.toBase64());
+}
+
+QPixmap Utils::pixmapFromString(const QString &data) {
+    QPixmap pixmap;
+    if (!data.isEmpty()) {
+        pixmap.loadFromData(QByteArray::fromBase64(data.toLatin1()), "PNG");
+    }
+    return pixmap;
+}
\ No newline at end of file
